pub enum CredentialReadMode {
Use,
Retry,
}Expand description
Whether an authoritative credential use may start a new physical read.
Variants
Use
Join an in-flight read or start one when the coordinator is not cooling down from a terminal store failure.
Retry
Join an in-flight read or explicitly clear cooldown and start one new generation.